import template from './sw-settings-captcha-select-v2.html.twig';
import deDE from './snippet/de-DE.json';
import enGB from './snippet/en-GB.json';

const { Component, Locale } = Shopware;

// Register snippets
Locale.extend('de-DE', deDE);
Locale.extend('en-GB', enGB);

console.log('[TurnstileReMaster] Overriding sw-settings-captcha-select-v2 component...');

Component.override('sw-settings-captcha-select-v2', {
    template, // Use the extended template

    computed: {
        // Override the computed property that generates the dropdown options
        captchaOptions() {
            console.log('[TurnstileReMaster] Computing captchaOptions...');
            console.log('[TurnstileReMaster] Current allCaptchaTypes:', this.allCaptchaTypes);

            // Build the base options using helper
            const options = this.buildBaseCaptchaOptions();
            console.log('[TurnstileReMaster] Base options:', JSON.parse(JSON.stringify(options)));

            // Check if CloudFlare captcha exists in the config data
            if (this.allCaptchaTypes && this.allCaptchaTypes.cloudFlareTurnstile) {
                console.log('[TurnstileReMaster] cloudFlareTurnstile found in allCaptchaTypes, adding.');
                // Add our captcha option
                options.push({
                    value: 'cloudFlareTurnstile', // Must match the key used in PHP/Migration
                    label: this.$tc('sw-settings-basic-information.captcha.label.cloudFlareTurnstile'),
                });
            } else {
                console.warn('[TurnstileReMaster] cloudFlareTurnstile NOT found in allCaptchaTypes!');
                if (this.allCaptchaTypes) {
                    console.warn('[TurnstileReMaster] Available keys:', Object.keys(this.allCaptchaTypes));
                }
            }

            // Sort options alphabetically by label (optional feature)
            options.sort((a, b) => a.label.localeCompare(b.label));

            console.log('[TurnstileReMaster] Final captchaOptions:', JSON.parse(JSON.stringify(options)));
            return options;
        },

        // Helper to build base options based on available data
        // Adapt this if Shopware adds/removes core captchas in future versions
        buildBaseCaptchaOptions() {
            const options = [];
            if (!this.allCaptchaTypes) {
                console.warn('[TurnstileReMaster] allCaptchaTypes is missing in buildBaseCaptchaOptions!');
                return [];
            }
            if (this.allCaptchaTypes.honeypot) options.push({ value: 'honeypot', label: this.$tc('sw-settings-basic-information.captcha.label.honeypot') });
            if (this.allCaptchaTypes.basicCaptcha) options.push({ value: 'basicCaptcha', label: this.$tc('sw-settings-basic-information.captcha.label.basicCaptcha') });
            if (this.allCaptchaTypes.googleReCaptchaV2) options.push({ value: 'googleReCaptchaV2', label: this.$tc('sw-settings-basic-information.captcha.label.googleReCaptchaV2') });
            if (this.allCaptchaTypes.googleReCaptchaV3) options.push({ value: 'googleReCaptchaV3', label: this.$tc('sw-settings-basic-information.captcha.label.googleReCaptchaV3') });
            // Add other core captchas here if necessary
            return options;
        }
    },

    // Debug methods for the template
    methods: {
        stringifyForDebug(value) {
            try {
                if (value && typeof value === 'object') {
                    return JSON.stringify(Object.keys(value));
                }
                return JSON.stringify(value);
            } catch (e) { return '[Error stringifying]'; }
        },
        getCloudflareTurnstileDataForDebug() {
            if (this.allCaptchaTypes && this.allCaptchaTypes.cloudFlareTurnstile) {
                try {
                    return JSON.stringify(this.allCaptchaTypes.cloudFlareTurnstile, null, 2);
                } catch (e) { return '[Error stringifying]'; }
            }
            return 'Not found in allCaptchaTypes';
        }
    }
});

console.log('[TurnstileReMaster] Override applied.');